//==============================================
//  copyright            : (C) 2003 by Will Stokes
//==============================================
//  This program is free software; you can redistribute it 
//  and/or modify it under the terms of the GNU General 
//  Public License as published by the Free Software 
//  Foundation; either version 2 of the License, or  
//  (at your option) any later version.         
//
//  As a special exception, Will Stokes gives permission to 
//  link this program with Qt non-commercial edition, and 
//  distribute the resulting executable, without including the 
//  source code for the Qt non-commercial edition in the 
//  source distribution. 
//==============================================

#ifndef GUI_LAYOUTWIDGET_H
#define GUI_LAYOUTWIDGET_H

#include <qwidget.h>

//--------------------
//forward declarations
class QLabel;
class QGridLayout;
class SubalbumsWidget;
class SubalbumWidget;
class PhotoEditWidget;
class Subalbum;
class Photo;
class Window;
//--------------------

//=====================================
/*! \brief Displays list of subalbums and a particular subalbum layout.
 *
 */
//=====================================

class LayoutWidget : public QWidget
{
public:
  ///Creates empty layout
  LayoutWidget(QWidget *parent=0, const char* name=0);
  
  ///Removes current subalbum widget. Creates
  ///new widget using new subalbum pointer
  void updateSubalbum(Subalbum* salbum, bool oldExists);

  ///Updates current subalbums name
  void updateSubalbumName(const QString& val);
  
  ///Updates the current subalbums image
  void updateSubalbumImage( QPixmap* val);  
  
  ///Returns a pointer to the subalbum
  SubalbumWidget* getSubalbum();
  
  ///Returns a pointer to the subalbums
  SubalbumsWidget* getSubalbums();
  
  ///Returns a pointer to the window
  Window* getWindow();
  
  ///Refreshes layout
  void refresh();
  
  ///Brings up edit dialog for specified photo 
  void editPhoto(Photo* photo);
  
  ///Tears down the edit dialog and returns to the layout for the selected subalbum
  void stopEdit(bool oldExists);
//----------------------
private:
  ///Window pointer
  Window* window;
  
  ///Grid items placed in
  QGridLayout* grid;

  ///Particular subalbum layout
  SubalbumWidget* subalbum;
  
  ///List of subalbums
  SubalbumsWidget* subalbums;

  ///Photo editing widget
  PhotoEditWidget* photoEdit;
//----------------------
};
//======================

#endif //GUI_LAYOUTWIDGET_H
