//==============================================
//  copyright            : (C) 2003 by Will Stokes
//==============================================
//  This program is free software; you can redistribute it 
//  and/or modify it under the terms of the GNU General 
//  Public License as published by the Free Software 
//  Foundation; either version 2 of the License, or  
//  (at your option) any later version.         
//
//  As a special exception, Will Stokes gives permission to 
//  link this program with Qt non-commercial edition, and 
//  distribute the resulting executable, without including the 
//  source code for the Qt non-commercial edition in the 
//  source distribution. 
//==============================================

//Systemwide includes
#include <qlayout.h>
#include <qpixmap.h>

//Projectwide includes
#include "window.h"
#include "titleWidget.h"
#include "layoutWidget.h"
#include "../config.h"

//==============================================
Window::Window( QWidget* parent,
                const char* name ) : 
                QWidget(parent,name)
{
  title = new TitleWidget(this, "title");
  layout = new LayoutWidget(this, "layout");

  //create new grid and add widgets
  grid = new QGridLayout( this, 2, 1, 0);
  grid->addWidget( title, 0, 0 );
  grid->addWidget( layout, 1, 0 );

  //set the layout widget to take up all remaining space
  grid->setRowStretch( 1, 1 );

  //set the background of the widget to be white
  setPaletteBackgroundColor( QColor(255, 255, 255) );
  
  //create and set application icon
  applicationIcon = new QPixmap(QString(IMAGE_PATH)+"albumShaperIcon.png");
  setIcon( *applicationIcon );
  setCaption( "Album Shaper  Will Stokes");
}
//==============================================
TitleWidget* Window::getTitle()
{
  return title;
}
//==============================================
LayoutWidget* Window::getLayout()
{
  return layout;
}
//==============================================
void Window::refresh()
{
  layout->refresh();
}
//==============================================
